@@ -280,8 +280,10 @@ def active_enhancers_vs_active_promoters(
     metric: str = "mean",
     window_size: int = 256,
     root: str = "datasets",
-    verbose: int = 2,
-    **kwargs: Dict
+    binarize: bool = False,
+    min_active_tpm_value: float = 1,
+    max_inactive_tpm_value: float = 1,
+    verbose: int = 2
 ):
     """Return epigenomic data and labels for given parameters.
 
@@ -305,6 +307,13 @@ def active_enhancers_vs_active_promoters(
         listed in the repository README file.
     root: str = "datasets"
         Where to store the downloaded data.
+        min_active_tpm_value: float = 1,
+        Minimum TPM value.
+    binarize: bool = False,
+        Whether to binarize the TPM values.
+    max_inactive_tpm_value: float = 1,
+        Maximum TPM value.
+        Values between the minimum and maximum will be dropped.
     verbose: int = 2,
         Verbosity level.
 
@@ -324,6 +333,9 @@ def active_enhancers_vs_active_promoters(
         only_inactive=False,
         load_enhancers=True,
         load_promoters=True,
+        binarize=binarize,
+        min_active_tpm_value=min_active_tpm_value,
+        max_inactive_tpm_value=max_inactive_tpm_value,
     )
 
 
@@ -334,8 +346,10 @@ def inactive_enhancers_vs_inactive_promoters(
     metric: str = "mean",
     window_size: int = 256,
     root: str = "datasets",
-    verbose: int = 2,
-    **kwargs: Dict
+    binarize: bool = False,
+    min_active_tpm_value: float = 1,
+    max_inactive_tpm_value: float = 1,
+    verbose: int = 2
 ):
     """Return epigenomic data and labels for given parameters.
 
@@ -359,6 +373,13 @@ def inactive_enhancers_vs_inactive_promoters(
         listed in the repository README file.
     root: str = "datasets"
         Where to store the downloaded data.
+    binarize: bool = False,
+        Whether to binarize the TPM values.
+    min_active_tpm_value: float = 1,
+        Minimum TPM value.
+    max_inactive_tpm_value: float = 1,
+        Maximum TPM value.
+        Values between the minimum and maximum will be dropped.
     verbose: int = 2,
         Verbosity level.
 
@@ -378,6 +399,9 @@ def inactive_enhancers_vs_inactive_promoters(
         only_inactive=True,
         load_enhancers=True,
         load_promoters=True,
+        binarize=binarize,
+        min_active_tpm_value=min_active_tpm_value,
+        max_inactive_tpm_value=max_inactive_tpm_value,
     )
 
 
